﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Web;
using System.Web.Http;
using DomainClasses;
using DataAccess;

namespace MvcApp.Controllers
{
    public class ScreencastController : ApiController
    {
        private ScreencastContext db = new ScreencastContext();

        // GET api/Screencast
        public IEnumerable<Screencast> GetScreencasts()
        {
            var screencasts = db.Screencasts.Include(s => s.Topic);
            return screencasts.AsEnumerable();
        }

        // GET api/Screencast/5
        public Screencast GetScreencast(int id)
        {
            Screencast screencast = db.Screencasts.Find(id);
            if (screencast == null)
            {
                throw new HttpResponseException(Request.CreateResponse(HttpStatusCode.NotFound));
            }

            return screencast;
        }

        // PUT api/Screencast/5
        public HttpResponseMessage PutScreencast(int id, Screencast screencast)
        {
            if (ModelState.IsValid && id == screencast.Id)
            {
                db.Entry(screencast).State = EntityState.Modified;

                try
                {
                    db.SaveChanges();
                }
                catch (DbUpdateConcurrencyException)
                {
                    return Request.CreateResponse(HttpStatusCode.NotFound);
                }

                return Request.CreateResponse(HttpStatusCode.OK);
            }
            else
            {
                return Request.CreateResponse(HttpStatusCode.BadRequest);
            }
        }

        // POST api/Screencast
        public HttpResponseMessage PostScreencast(Screencast screencast)
        {
            if (ModelState.IsValid)
            {
                db.Screencasts.Add(screencast);
                db.SaveChanges();

                HttpResponseMessage response = Request.CreateResponse(HttpStatusCode.Created, screencast);
                response.Headers.Location = new Uri(Url.Link("DefaultApi", new { id = screencast.Id }));
                return response;
            }
            else
            {
                return Request.CreateResponse(HttpStatusCode.BadRequest);
            }
        }

        // DELETE api/Screencast/5
        public HttpResponseMessage DeleteScreencast(int id)
        {
            Screencast screencast = db.Screencasts.Find(id);
            if (screencast == null)
            {
                return Request.CreateResponse(HttpStatusCode.NotFound);
            }

            db.Screencasts.Remove(screencast);

            try
            {
                db.SaveChanges();
            }
            catch (DbUpdateConcurrencyException)
            {
                return Request.CreateResponse(HttpStatusCode.NotFound);
            }

            return Request.CreateResponse(HttpStatusCode.OK, screencast);
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}