﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using DomainClasses;
using DataAccess;

namespace MvcApp.Controllers
{
    public class ScreencastMVCController : Controller
    {
        private ScreencastContext db = new ScreencastContext();

        //
        // GET: /ScreencastMVC/

        public ActionResult Index()
        {
            var screencasts = db.Screencasts.Include(s => s.Topic);
            return View(screencasts.ToList());
        }

        //
        // GET: /ScreencastMVC/Details/5

        public ActionResult Details(int id = 0)
        {
            Screencast screencast = db.Screencasts.Find(id);
            if (screencast == null)
            {
                return HttpNotFound();
            }
            return View(screencast);
        }

        //
        // GET: /ScreencastMVC/Create

        public ActionResult Create()
        {
            ViewBag.TopicId = new SelectList(db.Topics, "Id", "Name");
            return View();
        }

        //
        // POST: /ScreencastMVC/Create

        [HttpPost]
        public ActionResult Create(Screencast screencast)
        {
            if (ModelState.IsValid)
            {
                db.Screencasts.Add(screencast);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            ViewBag.TopicId = new SelectList(db.Topics, "Id", "Name", screencast.TopicId);
            return View(screencast);
        }

        //
        // GET: /ScreencastMVC/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Screencast screencast = db.Screencasts.Find(id);
            if (screencast == null)
            {
                return HttpNotFound();
            }
            ViewBag.TopicId = new SelectList(db.Topics, "Id", "Name", screencast.TopicId);
            return View(screencast);
        }

        //
        // POST: /ScreencastMVC/Edit/5

        [HttpPost]
        public ActionResult Edit(Screencast screencast)
        {
            if (ModelState.IsValid)
            {
                db.Entry(screencast).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.TopicId = new SelectList(db.Topics, "Id", "Name", screencast.TopicId);
            return View(screencast);
        }

        //
        // GET: /ScreencastMVC/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Screencast screencast = db.Screencasts.Find(id);
            if (screencast == null)
            {
                return HttpNotFound();
            }
            return View(screencast);
        }

        //
        // POST: /ScreencastMVC/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            Screencast screencast = db.Screencasts.Find(id);
            db.Screencasts.Remove(screencast);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}